import { Extension, Facet } from "@codemirror/state";
import { EditorView } from "@codemirror/view";
/**
 * A facet to define typable commands. No effort is made to prevent overrides,
 * collisions, etc.
 */
export declare const commandFacet: Facet<TypableCommand[], TypableCommand[]>;
/**
 * A command that can be typed in command mode `:`.
 */
export interface TypableCommand {
    name: string;
    aliases?: string[];
    help: string;
    /**
     * The handler for the command. The return type can specify a message,
     * and qualify it as an error if desired.
     */
    handler(view: EditorView, args: any[]): {
        message: string;
        error?: boolean;
    } | void;
}
/**
 * The main helix extension.
 *
 * It provides Helix-like keybindings, plus two panels to emulate the statusline and the commandline.
 */
export declare function helix(): Extension;
